BehaviorState

Enum BehaviorState 

#[repr(u8)]
pub enum BehaviorState { Idle = 0, Running = 1, Success = 2, Failure = 3, Skipped = 4, }
Behavior state.

Implementation is as in BehaviorTree.CPP to be able to cooperate with Groot2. IMPORTANT: Behaviors should NEVER return IDLE from a tick.

Variants



Idle = 0

Behavior is not executing.



Running = 1

Behavior is still executing.



Success = 2

Behavior finished with success.



Failure = 3

Behavior execution failed.



Skipped = 4

Behavior has been skipped.

Implementations

Source

impl BehaviorState

pub const fn is_active(&self) -> bool

Check if state is signaling that the behavior is active

pub const fn is_completed(&self) -> bool

Check if state is signaling that the behavior is completed

pub const fn as_str(&self) -> &'static str

Provide kind as a static str reference.